@@ -1,11 +1,13 @@
 import importlib
 from .cdn_client import CdnClient
 from .nas_client import NasClient
+from .dds_client import DdsClient
 from proxy_tools import proxy
 
 prod_mapper = {
     'cdn': CdnClient,
-    'nas': NasClient
+    'nas': NasClient,
+    'dds': DdsClient
 }
 
 
@@ -24,3 +26,8 @@ def cdn_client():
 @proxy
 def nas_client():
     return get_current_client('nas')
+
+
+@proxy
+def dds_client():
+    return get_current_client('dds')
