@@ -1,5 +1,6 @@
 from .client import HuaweiClient
-from huaweicloudsdkevs.v2 import EvsClient, CreateVolumeRequest, ListVolumesRequest, ShowJobRequest, DeleteVolumeRequest
+from huaweicloudsdkevs.v2 import EvsClient, CreateVolumeRequest, ListVolumesRequest, ShowJobRequest, \
+    DeleteVolumeRequest, ResizeVolumeRequest, ShowVolumeRequest
 from huaweicloudsdkevs.v2.region.evs_region import EvsRegion
 
 
@@ -23,6 +24,14 @@ class HuaweiEvsClient(HuaweiClient):
         request = ListVolumesRequest(id=volume_id)
         return self.evs_client.list_volumes(request).volumes
 
+    def show_volume(self, volume_id=None):
+        request = ShowVolumeRequest(volume_id=volume_id)
+        return self.evs_client.show_volume(request).volume
+
+    def resize_volume(self, volume_id=None, body_params=None):
+        request = ResizeVolumeRequest(volume_id=volume_id, body=body_params)
+        return self.evs_client.resize_volume(request)
+
     def show_job(self, job_id=None):
         request = ShowJobRequest(job_id=job_id)
         return self.evs_client.show_job(request)
